==> piwigo-2.5.3.zip: piwigo/plugins/LocalFilesEditor/language/it_IT/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configurazione locale';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Lingue';
$lang['locfiledit_onglet_plug'] = 'Plugin Personale';
$lang['locfiledit_cant_save'] = 'Il file corrente non è scrivibile. Verificare i permessi di scrittura (chmod) della directory "local/".';
$lang['locfiledit_newfile'] = 'Il file non esiste fino a quando qualche informazione verrà inserita di seguito. Una volta che le informazioni sono inserite e salvate, il file verrà creato.';
$lang['locfiledit_save_config'] = 'File salvato con successo';
$lang['locfiledit_show_default'] = 'Visualizzare file di riferimento:';
$lang['locfiledit_save_bak'] = 'Una copia di backup del file sarà creata durante la fase di salvataggio.';
$lang['locfiledit_saved_bak'] = 'Una copia di backup è stata creata (%s)';
$lang['locfiledit_save_file'] = 'Salvare il file';
$lang['locfiledit_choose_file'] = 'Scegliere un file da modificare';
$lang['locfiledit_edit'] = 'Modificare';
$lang['locfiledit_restore'] = 'Caricare il file di backup';
$lang['locfiledit_restore_confirm'] = 'Si prega di confermare?
Il ripristino non sarà effettivo fino al successivo salvataggio.';
$lang['locfiledit_bak_loaded1'] = 'Copia di backup caricata.';
$lang['locfiledit_bak_loaded2'] = 'E\' necessario salvare il file per ripristinarlo.';
$lang['locfiledit_syntax_error'] = 'Errore di sintassi! Impossible salvare il file.';
$lang['locfiledit_new_tpl'] = 'Creare un nuovo file';
$lang['locfiledit_new_filename'] = 'Nome file';
$lang['locfiledit_model'] = 'Modello';
$lang['locfiledit_empty_page'] = 'Pagina vuota';
$lang['locfiledit_parent_directory'] = 'Directory parente';
$lang['locfiledit_filename_error'] = 'Caratteri vietati nel nome del file.';
$lang['locfiledit_file_already_exists'] = 'Il file esiste già.';
$lang['locfiledit_model_error'] = 'E\' necessario scegliere un modello.';
$lang['locfiledit_empty_filename'] = 'E\' necessario inserire il nome del file.';
$lang['locfiledit_webmaster_only'] = 'Solo i webmasters sono autorizzati a creare o modificare i file locali.';
?>

==> piwigo-16.2.0.zip: piwigo/plugins/LocalFilesEditor/language/it_IT/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Configurazione locale';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Templates';
$lang['locfiledit_onglet_lang'] = 'Lingue';
$lang['locfiledit_onglet_plug'] = 'Plugin Personale';
$lang['locfiledit_cant_save'] = 'Il file corrente non è scrivibile. Verifica i permessi di scrittura (chmod) della directory "local/".';
$lang['locfiledit_newfile'] = 'Il file non esiste fino a quando qualche informazione verrà inserita di seguito. Una volta che le informazioni sono inserite e salvate, il file verrà creato.';
$lang['locfiledit_save_config'] = 'File salvato con successo';
$lang['locfiledit_show_default'] = 'Visualizza file di riferimento:';
$lang['locfiledit_save_bak'] = 'Una copia di backup del file sarà creata durante la fase di salvataggio.';
$lang['locfiledit_saved_bak'] = 'Una copia di backup è stata creata (%s)';
$lang['locfiledit_save_file'] = 'Salva il file';
$lang['locfiledit_choose_file'] = 'Scegli un file da modificare';
$lang['locfiledit_edit'] = 'Modifica';
$lang['locfiledit_restore'] = 'Caricare il file di backup';
$lang['locfiledit_restore_confirm'] = 'Si prega di confermare?
Il ripristino non sarà effettivo fino al successivo salvataggio.';
$lang['locfiledit_bak_loaded1'] = 'Copia di backup caricata.';
$lang['locfiledit_bak_loaded2'] = 'Devi salvare il file per ripristinarlo.';
$lang['locfiledit_syntax_error'] = 'Errore di sintassi! Impossibile salvare il file.';
$lang['locfiledit_new_tpl'] = 'Crea un nuovo file';
$lang['locfiledit_new_filename'] = 'Nome file';
$lang['locfiledit_model'] = 'Modello';
$lang['locfiledit_empty_page'] = 'Pagina vuota';
$lang['locfiledit_parent_directory'] = 'Directory parente';
$lang['locfiledit_filename_error'] = 'Caratteri vietati nel nome del file.';
$lang['locfiledit_file_already_exists'] = 'Il file esiste già.';
$lang['locfiledit_model_error'] = 'Devi scegliere un modello.';
$lang['locfiledit_empty_filename'] = 'Devi inserire il nome del file.';
$lang['locfiledit_webmaster_only'] = 'Solo i webmasters sono autorizzati a creare o modificare i file locali.';
$lang['Customize CSS'] = 'Personalizza CSS';
